@@ -32,11 +32,11 @@
 using System;
 using System.Collections.Generic;
 
-using Mono.Addins;
-
 using Gtk;
 using ScrolledWindow = Gtk.ScrolledWindow;
 
+using Mono.Addins;
+
 using Hyena;
 using Hyena.Widgets;
 using Hyena.Data.Gui;
@@ -101,29 +101,29 @@ namespace Banshee.LiveRadio
         {
             base.Name = plugin.Name;
             this.plugin = plugin;
-            
+
             InitializeViews ();
-            
+
             string position = ForcePosition == null ? BrowserPosition.Get () : ForcePosition;
             if (position == "top") {
                 LayoutTop ();
             } else {
                 LayoutLeft ();
             }
-            
+
             plugin.GenreListLoaded += OnPluginGenreListLoaded;
             plugin.RequestResultRetrieved += OnPluginRequestResultRetrieved;
-            
+
             if (ForcePosition != null) {
                 return;
             }
-            
+
             if (ServiceManager.Contains ("InterfaceActionService")) {
                 action_service = ServiceManager.Get<InterfaceActionService> ();
-                
+
                 if (action_service.FindActionGroup ("BrowserView") == null) {
                     browser_view_actions = new ActionGroup ("BrowserView");
-                    
+
                     browser_view_actions.Add (new RadioActionEntry [] {
                         new RadioActionEntry ("BrowserLeftAction", null,
                             AddinManager.CurrentLocalizer.GetString ("Browser on Left"), null,
@@ -145,7 +145,7 @@ namespace Banshee.LiveRadio
                     action_service.AddActionGroup (browser_view_actions);
                     action_service.UIManager.AddUiFromString (menu_xml);
                 }
-                
+
                 (action_service.FindAction ("BrowserView.BrowserLeftAction") as RadioAction).Changed += OnViewModeChanged;
                 (action_service.FindAction ("BrowserView.BrowserTopAction") as RadioAction).Changed += OnViewModeChanged;
                 action_service.FindAction ("BrowserView.BrowserVisibleAction").Activated += OnToggleBrowser;
@@ -224,8 +224,8 @@ namespace Banshee.LiveRadio
             faketrack.TrackTitle = info;
             faketrack.ArtistName = info;
             faketrack.AlbumArtist = info;
-            faketrack.Uri = new Banshee.Base.SafeUri ("http://test.com/test.pls");
-    
+            faketrack.Uri = new SafeUri ("http://test.com/test.pls");
+
             fakeresult.Add (faketrack);
             plugin.PluginSource.SetStations (fakeresult);
             main_scrolled_window.Sensitive = false;
@@ -287,17 +287,17 @@ namespace Banshee.LiveRadio
         private ScrolledWindow SetupView (Widget view)
         {
             ScrolledWindow window = null;
-            
+
             if (ApplicationContext.CommandLine.Contains ("smooth-scroll")) {
                 window = new SmoothScrolledWindow ();
             } else {
                 window = new ScrolledWindow ();
             }
-            
+
             window.Add (view);
             window.HscrollbarPolicy = PolicyType.Automatic;
             window.VscrollbarPolicy = PolicyType.Automatic;
-            
+
             return window;
         }
 
@@ -310,7 +310,7 @@ namespace Banshee.LiveRadio
             if (container != null && main_scrolled_window != null) {
                 container.Remove (main_scrolled_window);
             }
-            
+
             if (container != null) {
                 Remove (container);
             }
@@ -341,7 +341,7 @@ namespace Banshee.LiveRadio
         private void Layout (bool top)
         {
             Reset ();
-            
+
             container = GetPane (!top);
             filter_box = new LiveRadioFilterView ();
             filter_box.Sensitive = false;
@@ -352,7 +352,7 @@ namespace Banshee.LiveRadio
             container.Pack1 (filter_box, false, false);
             container.Pack2 (main_scrolled_window, true, false);
             browser_container = filter_box;
-            
+
             container.Position = top ? 175 : 275;
             ShowPack ();
         }
@@ -479,10 +479,10 @@ namespace Banshee.LiveRadio
         private void OnToggleBrowser (object o, EventArgs args)
         {
             ToggleAction action = (ToggleAction)o;
-            
+
             browser_container.Visible = action.Active && ActiveSourceCanHasBrowser;
             BrowserVisible.Set (action.Active);
-            
+
         }
 
         protected bool ActiveSourceCanHasBrowser {
@@ -510,11 +510,11 @@ namespace Banshee.LiveRadio
             if (track_source == null) {
                 return false;
             }
-            
+
             this.source = source;
-            
+
             track_view.SetModel (track_source.TrackModel);
-            
+
             return true;
         }
 
