@@ -27,12 +27,9 @@
 //
 
 using System;
-using System.IO;
-using System.Text;
 using System.Xml;
 using System.Collections.Generic;
 
-using Banshee.Base;
 using Banshee.Collection.Database;
 
 using Hyena;
@@ -64,6 +61,7 @@ namespace Banshee.LiveRadio.Plugins
             if (!Int32.TryParse(HttpTimeoutEntry.Get (), out http_timeout_seconds))
                 http_timeout_seconds = 20;
             proxy_url = ProxyUrlEntry.Get ();
+            SetWebIcon ("http://o.aolcdn.com/shoutcast/images/sc_favicon.ico");
         }
 
         /// <summary>
@@ -121,9 +119,9 @@ namespace Banshee.LiveRadio.Plugins
                     RaiseErrorReturned ("XML Parse Error", ex.Message);
                     continue;
                 }
-                
+
             }
-            
+
             new_genres.Sort ();
             genres = new_genres;
 
@@ -192,13 +190,13 @@ namespace Banshee.LiveRadio.Plugins
                     string bitrate = xml_attributes.GetNamedItem ("br").InnerText;
                     int id_int;
                     int bitrate_int;
-                    
+
                     if (!Int32.TryParse (id.Trim (), out id_int)) {
                         continue; //Something wrong with id, skip this
                     }
 
                     DatabaseTrackInfo new_station = new DatabaseTrackInfo ();
-    
+
                     new_station.Uri = new SafeUri (base_url + tunein_url + "?id=" + id);
                     new_station.ArtistName = "www.shoutcast.com";
                     new_station.Genre = genre;
@@ -209,7 +207,7 @@ namespace Banshee.LiveRadio.Plugins
                     new_station.ExternalId = id_int;
                     new_station.PrimarySource = source;
                     new_station.IsLive = true;
-                    Int32.TryParse (bitrate.Trim (), out bitrate_int);                    
+                    Int32.TryParse (bitrate.Trim (), out bitrate_int);
                     new_station.BitRate = bitrate_int;
                     new_station.IsLive = true;
 
@@ -262,5 +260,5 @@ namespace Banshee.LiveRadio.Plugins
 
 
     }
-    
+
 }
